# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dataclay/communication/grpc/messages/dataservice/dataservice_messages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dataclay.communication.grpc.messages.common import common_messages_pb2 as dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dataclay/communication/grpc/messages/dataservice/dataservice_messages.proto',
  package='dataclay.communication.grpc.dataservice',
  syntax='proto3',
  serialized_options=_b('\n0dataclay.communication.grpc.messages.dataserviceP\000'),
  serialized_pb=_b('\nKdataclay/communication/grpc/messages/dataservice/dataservice_messages.proto\x12\'dataclay.communication.grpc.dataservice\x1a\x41\x64\x61taclay/communication/grpc/messages/common/common_messages.proto\"`\n\x14InitBackendIDRequest\x12H\n\tbackendID\x18\x01 \x01(\x0b\x32\x35.dataclay.communication.grpc.common.StorageLocationID\"\x82\x01\n$AssociateExecutionEnvironmentRequest\x12Z\n\x16\x65xecutionEnvironmentID\x18\x01 \x01(\x0b\x32:.dataclay.communication.grpc.common.ExecutionEnvironmentID\"\xd3\x01\n\x18\x44\x65ployMetaClassesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12m\n\x0e\x64\x65ploymentPack\x18\x02 \x03(\x0b\x32U.dataclay.communication.grpc.dataservice.DeployMetaClassesRequest.DeploymentPackEntry\x1a\x35\n\x13\x44\x65ploymentPackEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x05\n\x14\x44\x65ployClassesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12k\n\x0f\x63lassesToDeploy\x18\x02 \x03(\x0b\x32R.dataclay.communication.grpc.dataservice.DeployClassesRequest.ClassesToDeployEntry\x12]\n\x08\x63lassIds\x18\x03 \x03(\x0b\x32K.dataclay.communication.grpc.dataservice.DeployClassesRequest.ClassIdsEntry\x12[\n\x07\x61spects\x18\x04 \x03(\x0b\x32J.dataclay.communication.grpc.dataservice.DeployClassesRequest.AspectsEntry\x12W\n\x05yamls\x18\x05 \x03(\x0b\x32H.dataclay.communication.grpc.dataservice.DeployClassesRequest.YamlsEntry\x1a\x36\n\x14\x43lassesToDeployEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a`\n\rClassIdsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12>\n\x05value\x18\x02 \x01(\x0b\x32/.dataclay.communication.grpc.common.MetaClassID:\x02\x38\x01\x1a.\n\x0c\x41spectsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a,\n\nYamlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"o\n\x12\x45nrichClassRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tclassname\x18\x02 \x01(\t\x12\x15\n\rclassToDeploy\x18\x03 \x01(\x0c\x12\x0e\n\x06\x61spect\x18\x04 \x01(\x0c\x12\x0c\n\x04yaml\x18\x05 \x01(\x0c\"\xe8\x03\n\x1cNewPersistentInstanceRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12@\n\x07\x63lassID\x18\x02 \x01(\x0b\x32/.dataclay.communication.grpc.common.MetaClassID\x12N\n\x10implementationID\x18\x03 \x01(\x0b\x32\x34.dataclay.communication.grpc.common.ImplementationID\x12m\n\x0cifaceBitMaps\x18\x04 \x03(\x0b\x32W.dataclay.communication.grpc.dataservice.NewPersistentInstanceRequest.IfaceBitMapsEntry\x12P\n\x06params\x18\x05 \x01(\x0b\x32@.dataclay.communication.grpc.common.SerializedParametersOrReturn\x1a\x33\n\x11IfaceBitMapsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xa3\x01\n\x1dNewPersistentInstanceResponse\x12>\n\x08objectID\x18\x01 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\"\xfd\x01\n\x13StoreObjectsRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12P\n\x07objects\x18\x02 \x03(\x0b\x32?.dataclay.communication.grpc.common.ObjectWithDataParamOrReturn\x12\x0e\n\x06moving\x18\x03 \x01(\x08\x12\x42\n\x0cidsWithAlias\x18\x04 \x03(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\"\x9f\x01\n\x12NewMetaDataRequest\x12Y\n\x07mdInfos\x18\x01 \x03(\x0b\x32H.dataclay.communication.grpc.dataservice.NewMetaDataRequest.MdInfosEntry\x1a.\n\x0cMdInfosEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xad\x01\n\x16GetCopyOfObjectRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12>\n\x08objectID\x18\x02 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x11\n\trecursive\x18\x03 \x01(\x08\"\xac\x01\n\x17GetCopyOfObjectResponse\x12M\n\x03ret\x18\x01 \x01(\x0b\x32@.dataclay.communication.grpc.common.SerializedParametersOrReturn\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\"\xf1\x01\n\x13UpdateObjectRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12\x42\n\x0cintoObjectID\x18\x02 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12T\n\nfromObject\x18\x03 \x01(\x0b\x32@.dataclay.communication.grpc.common.SerializedParametersOrReturn\"\xb9\x01\n\x11GetObjectsRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12?\n\tobjectIDS\x18\x02 \x03(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x11\n\trecursive\x18\x03 \x01(\x08\x12\x0e\n\x06moving\x18\x04 \x01(\x08\"\xaa\x01\n\x12GetObjectsResponse\x12P\n\x07objects\x18\x01 \x03(\x0b\x32?.dataclay.communication.grpc.common.ObjectWithDataParamOrReturn\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\"\xac\x01\n\x1aGetFederatedObjectsRequest\x12M\n\rextDataClayID\x18\x01 \x01(\x0b\x32\x36.dataclay.communication.grpc.common.DataClayInstanceID\x12?\n\tobjectIDS\x18\x02 \x03(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\"\xb3\x01\n\x1bGetFederatedObjectsResponse\x12P\n\x07objects\x18\x01 \x03(\x0b\x32?.dataclay.communication.grpc.common.ObjectWithDataParamOrReturn\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\"\xab\x01\n\x13\x46ilterObjectRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12>\n\x08objectID\x18\x02 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x12\n\nconditions\x18\x03 \x01(\t\"\xa9\x01\n\x14\x46ilterObjectResponse\x12M\n\x03ret\x18\x01 \x01(\x0b\x32@.dataclay.communication.grpc.common.SerializedParametersOrReturn\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\"\xa2\x01\n\x1dGetReferencedObjectIDsRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12?\n\tobjectIDS\x18\x02 \x03(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\"\xa5\x01\n\x1eGetReferencedObjectIDsResponse\x12?\n\tobjectIDs\x18\x01 \x03(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\"\xab\x01\n\x15MakePersistentRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12P\n\x06params\x18\x02 \x01(\x0b\x32@.dataclay.communication.grpc.common.SerializedParametersOrReturn\"\xa5\x01\n\x0f\x46\x65\x64\x65rateRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12P\n\x06params\x18\x02 \x01(\x0b\x32@.dataclay.communication.grpc.common.SerializedParametersOrReturn\"\x96\x01\n\x11UnfederateRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12?\n\tobjectIDs\x18\x02 \x03(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\"\xc2\x02\n\x1c\x45xecuteImplementationRequest\x12>\n\x08objectID\x18\x01 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12N\n\x10implementationID\x18\x02 \x01(\x0b\x32\x34.dataclay.communication.grpc.common.ImplementationID\x12@\n\tsessionID\x18\x03 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12P\n\x06params\x18\x04 \x01(\x0b\x32@.dataclay.communication.grpc.common.SerializedParametersOrReturn\"\xb2\x01\n\x1d\x45xecuteImplementationResponse\x12M\n\x03ret\x18\x01 \x01(\x0b\x32@.dataclay.communication.grpc.common.SerializedParametersOrReturn\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\"\x9c\x01\n\x15SetNotVolatileRequest\x12>\n\x08objectID\x18\x01 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x43\n\x0cstoraDataSet\x18\x02 \x01(\x0b\x32-.dataclay.communication.grpc.common.DataSetID\"\xab\x01\n\x11NewVersionRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12>\n\x08objectID\x18\x02 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x14\n\x0cmetadataInfo\x18\x03 \x01(\t\"\xb2\x02\n\x12NewVersionResponse\x12>\n\x08objectID\x18\x01 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x63\n\x0cversionedIDs\x18\x02 \x03(\x0b\x32M.dataclay.communication.grpc.dataservice.NewVersionResponse.VersionedIDsEntry\x12\x42\n\x07\x65xcInfo\x18\x03 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\x1a\x33\n\x11VersionedIDsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"r\n\x19\x43onsolidateVersionRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12\x13\n\x0bversionInfo\x18\x02 \x01(\t\"\xae\x01\n\x14UpsertObjectsRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12T\n\x0b\x62ytesUpdate\x18\x02 \x03(\x0b\x32?.dataclay.communication.grpc.common.ObjectWithDataParamOrReturn\"\xa8\x01\n\x11NewReplicaRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12>\n\x08objectID\x18\x02 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x11\n\trecursive\x18\x03 \x01(\x08\"\x9d\x01\n\x12NewReplicaResponse\x12\x43\n\rreplicatedIDs\x18\x01 \x03(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\"\xf8\x01\n\x12MoveObjectsRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12>\n\x08objectID\x18\x02 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12M\n\tdestLocID\x18\x03 \x01(\x0b\x32:.dataclay.communication.grpc.common.ExecutionEnvironmentID\x12\x11\n\trecursive\x18\x04 \x01(\x08\"\x9d\x01\n\x13MoveObjectsResponse\x12\x42\n\x0cmovedObjects\x18\x01 \x03(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\"\x89\x02\n\x14RemoveObjectsRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\x12?\n\tobjectIDs\x18\x02 \x03(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x11\n\trecursive\x18\x03 \x01(\x08\x12\x0e\n\x06moving\x18\x04 \x01(\x08\x12K\n\x07newHint\x18\x05 \x01(\x0b\x32:.dataclay.communication.grpc.common.ExecutionEnvironmentID\"\xad\x01\n\x10JumpMapThreadMsg\x12\x63\n\rjumpMapThread\x18\x01 \x03(\x0b\x32L.dataclay.communication.grpc.dataservice.JumpMapThreadMsg.JumpMapThreadEntry\x1a\x34\n\x12JumpMapThreadEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfe\x01\n\x15RemoveObjectsResponse\x12j\n\x0eremovedObjects\x18\x01 \x03(\x0b\x32R.dataclay.communication.grpc.dataservice.RemoveObjectsResponse.RemovedObjectsEntry\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\x1a\x35\n\x13RemovedObjectsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbd\x01\n\x15MigrateObjectsRequest\x12l\n\x0f\x64\x65stStorageLocs\x18\x01 \x03(\x0b\x32S.dataclay.communication.grpc.dataservice.MigrateObjectsRequest.DestStorageLocsEntry\x1a\x36\n\x14\x44\x65stStorageLocsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"M\n\x0fMigratedObjects\x12:\n\x04objs\x18\x01 \x03(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\"\x87\x03\n\x16MigrateObjectsResponse\x12g\n\x0cmigratedObjs\x18\x01 \x03(\x0b\x32Q.dataclay.communication.grpc.dataservice.MigrateObjectsResponse.MigratedObjsEntry\x12Q\n\x0fnonMigratedObjs\x18\x02 \x01(\x0b\x32\x38.dataclay.communication.grpc.dataservice.MigratedObjects\x12\x42\n\x07\x65xcInfo\x18\x03 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\x1am\n\x11MigratedObjsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12G\n\x05value\x18\x02 \x01(\x0b\x32\x38.dataclay.communication.grpc.dataservice.MigratedObjects:\x02\x38\x01\"(\n\x16\x41\x63tivateTracingRequest\x12\x0e\n\x06taskid\x18\x01 \x01(\x05\"[\n\x17\x43loseSessionInDSRequest\x12@\n\tsessionID\x18\x01 \x01(\x0b\x32-.dataclay.communication.grpc.common.SessionID\"\x8f\x03\n\x12\x44iskCollectRequest\x12O\n\x0b\x65pochNodeID\x18\x01 \x01(\x0b\x32:.dataclay.communication.grpc.common.ExecutionEnvironmentID\x12L\n\x08ringPath\x18\x02 \x03(\x0b\x32:.dataclay.communication.grpc.common.ExecutionEnvironmentID\x12@\n\ncandidates\x18\x03 \x03(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x63\n\x0crefsToUpdate\x18\x04 \x03(\x0b\x32M.dataclay.communication.grpc.dataservice.DiskCollectRequest.RefsToUpdateEntry\x1a\x33\n\x11RefsToUpdateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"e\n#GetClassIDFromObjectInMemoryRequest\x12>\n\x08objectID\x18\x01 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\"\xac\x01\n$GetClassIDFromObjectInMemoryResponse\x12@\n\x07\x63lassID\x18\x01 \x01(\x0b\x32/.dataclay.communication.grpc.common.MetaClassID\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\"\xc0\x01\n\x10StoreToDBRequest\x12Z\n\x16\x65xecutionEnvironmentID\x18\x01 \x01(\x0b\x32:.dataclay.communication.grpc.common.ExecutionEnvironmentID\x12>\n\x08objectID\x18\x02 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x10\n\x08objBytes\x18\x03 \x01(\x0c\"\xae\x01\n\x10GetFromDBRequest\x12Z\n\x16\x65xecutionEnvironmentID\x18\x01 \x01(\x0b\x32:.dataclay.communication.grpc.common.ExecutionEnvironmentID\x12>\n\x08objectID\x18\x02 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\"i\n\x11GetFromDBResponse\x12\x10\n\x08objBytes\x18\x01 \x01(\x0c\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\"\xd0\x01\n\x11UpdateToDBRequest\x12Z\n\x16\x65xecutionEnvironmentID\x18\x01 \x01(\x0b\x32:.dataclay.communication.grpc.common.ExecutionEnvironmentID\x12>\n\x08objectID\x18\x02 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x10\n\x08objBytes\x18\x03 \x01(\x0c\x12\r\n\x05\x64irty\x18\x04 \x01(\x08\"\xaf\x01\n\x11\x44\x65leteToDBRequest\x12Z\n\x16\x65xecutionEnvironmentID\x18\x01 \x01(\x0b\x32:.dataclay.communication.grpc.common.ExecutionEnvironmentID\x12>\n\x08objectID\x18\x02 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\"\xac\x01\n\x11UpdateRefsRequest\x12\x62\n\x0crefsToUpdate\x18\x01 \x03(\x0b\x32L.dataclay.communication.grpc.dataservice.UpdateRefsRequest.RefsToUpdateEntry\x1a\x33\n\x11RefsToUpdateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\xad\x01\n\x1dGetRetainedReferencesResponse\x12H\n\x12retainedReferences\x18\x01 \x03(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\"O\n\rExistsRequest\x12>\n\x08objectID\x18\x01 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\"d\n\x0e\x45xistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfo\"S\n\x11\x45xistsInDBRequest\x12>\n\x08objectID\x18\x01 \x01(\x0b\x32,.dataclay.communication.grpc.common.ObjectID\"h\n\x12\x45xistsInDBResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\x12\x42\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x31.dataclay.communication.grpc.common.ExceptionInfoB4\n0dataclay.communication.grpc.messages.dataserviceP\x00\x62\x06proto3')
  ,
  dependencies=[dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2.DESCRIPTOR,])




_INITBACKENDIDREQUEST = _descriptor.Descriptor(
  name='InitBackendIDRequest',
  full_name='dataclay.communication.grpc.dataservice.InitBackendIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='backendID', full_name='dataclay.communication.grpc.dataservice.InitBackendIDRequest.backendID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=283,
)


_ASSOCIATEEXECUTIONENVIRONMENTREQUEST = _descriptor.Descriptor(
  name='AssociateExecutionEnvironmentRequest',
  full_name='dataclay.communication.grpc.dataservice.AssociateExecutionEnvironmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executionEnvironmentID', full_name='dataclay.communication.grpc.dataservice.AssociateExecutionEnvironmentRequest.executionEnvironmentID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=416,
)


_DEPLOYMETACLASSESREQUEST_DEPLOYMENTPACKENTRY = _descriptor.Descriptor(
  name='DeploymentPackEntry',
  full_name='dataclay.communication.grpc.dataservice.DeployMetaClassesRequest.DeploymentPackEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.DeployMetaClassesRequest.DeploymentPackEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.DeployMetaClassesRequest.DeploymentPackEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=577,
  serialized_end=630,
)

_DEPLOYMETACLASSESREQUEST = _descriptor.Descriptor(
  name='DeployMetaClassesRequest',
  full_name='dataclay.communication.grpc.dataservice.DeployMetaClassesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='dataclay.communication.grpc.dataservice.DeployMetaClassesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploymentPack', full_name='dataclay.communication.grpc.dataservice.DeployMetaClassesRequest.deploymentPack', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEPLOYMETACLASSESREQUEST_DEPLOYMENTPACKENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=630,
)


_DEPLOYCLASSESREQUEST_CLASSESTODEPLOYENTRY = _descriptor.Descriptor(
  name='ClassesToDeployEntry',
  full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.ClassesToDeployEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.ClassesToDeployEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.ClassesToDeployEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1062,
  serialized_end=1116,
)

_DEPLOYCLASSESREQUEST_CLASSIDSENTRY = _descriptor.Descriptor(
  name='ClassIdsEntry',
  full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.ClassIdsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.ClassIdsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.ClassIdsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1118,
  serialized_end=1214,
)

_DEPLOYCLASSESREQUEST_ASPECTSENTRY = _descriptor.Descriptor(
  name='AspectsEntry',
  full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.AspectsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.AspectsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.AspectsEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1216,
  serialized_end=1262,
)

_DEPLOYCLASSESREQUEST_YAMLSENTRY = _descriptor.Descriptor(
  name='YamlsEntry',
  full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.YamlsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.YamlsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.YamlsEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1264,
  serialized_end=1308,
)

_DEPLOYCLASSESREQUEST = _descriptor.Descriptor(
  name='DeployClassesRequest',
  full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='classesToDeploy', full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.classesToDeploy', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='classIds', full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.classIds', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aspects', full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.aspects', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yamls', full_name='dataclay.communication.grpc.dataservice.DeployClassesRequest.yamls', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEPLOYCLASSESREQUEST_CLASSESTODEPLOYENTRY, _DEPLOYCLASSESREQUEST_CLASSIDSENTRY, _DEPLOYCLASSESREQUEST_ASPECTSENTRY, _DEPLOYCLASSESREQUEST_YAMLSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=1308,
)


_ENRICHCLASSREQUEST = _descriptor.Descriptor(
  name='EnrichClassRequest',
  full_name='dataclay.communication.grpc.dataservice.EnrichClassRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='dataclay.communication.grpc.dataservice.EnrichClassRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='classname', full_name='dataclay.communication.grpc.dataservice.EnrichClassRequest.classname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='classToDeploy', full_name='dataclay.communication.grpc.dataservice.EnrichClassRequest.classToDeploy', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aspect', full_name='dataclay.communication.grpc.dataservice.EnrichClassRequest.aspect', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='dataclay.communication.grpc.dataservice.EnrichClassRequest.yaml', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1310,
  serialized_end=1421,
)


_NEWPERSISTENTINSTANCEREQUEST_IFACEBITMAPSENTRY = _descriptor.Descriptor(
  name='IfaceBitMapsEntry',
  full_name='dataclay.communication.grpc.dataservice.NewPersistentInstanceRequest.IfaceBitMapsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.NewPersistentInstanceRequest.IfaceBitMapsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.NewPersistentInstanceRequest.IfaceBitMapsEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1861,
  serialized_end=1912,
)

_NEWPERSISTENTINSTANCEREQUEST = _descriptor.Descriptor(
  name='NewPersistentInstanceRequest',
  full_name='dataclay.communication.grpc.dataservice.NewPersistentInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.NewPersistentInstanceRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='classID', full_name='dataclay.communication.grpc.dataservice.NewPersistentInstanceRequest.classID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='implementationID', full_name='dataclay.communication.grpc.dataservice.NewPersistentInstanceRequest.implementationID', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ifaceBitMaps', full_name='dataclay.communication.grpc.dataservice.NewPersistentInstanceRequest.ifaceBitMaps', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='dataclay.communication.grpc.dataservice.NewPersistentInstanceRequest.params', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_NEWPERSISTENTINSTANCEREQUEST_IFACEBITMAPSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1424,
  serialized_end=1912,
)


_NEWPERSISTENTINSTANCERESPONSE = _descriptor.Descriptor(
  name='NewPersistentInstanceResponse',
  full_name='dataclay.communication.grpc.dataservice.NewPersistentInstanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.NewPersistentInstanceResponse.objectID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.NewPersistentInstanceResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1915,
  serialized_end=2078,
)


_STOREOBJECTSREQUEST = _descriptor.Descriptor(
  name='StoreObjectsRequest',
  full_name='dataclay.communication.grpc.dataservice.StoreObjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.StoreObjectsRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objects', full_name='dataclay.communication.grpc.dataservice.StoreObjectsRequest.objects', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='moving', full_name='dataclay.communication.grpc.dataservice.StoreObjectsRequest.moving', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='idsWithAlias', full_name='dataclay.communication.grpc.dataservice.StoreObjectsRequest.idsWithAlias', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2081,
  serialized_end=2334,
)


_NEWMETADATAREQUEST_MDINFOSENTRY = _descriptor.Descriptor(
  name='MdInfosEntry',
  full_name='dataclay.communication.grpc.dataservice.NewMetaDataRequest.MdInfosEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.NewMetaDataRequest.MdInfosEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.NewMetaDataRequest.MdInfosEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2450,
  serialized_end=2496,
)

_NEWMETADATAREQUEST = _descriptor.Descriptor(
  name='NewMetaDataRequest',
  full_name='dataclay.communication.grpc.dataservice.NewMetaDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mdInfos', full_name='dataclay.communication.grpc.dataservice.NewMetaDataRequest.mdInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_NEWMETADATAREQUEST_MDINFOSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2337,
  serialized_end=2496,
)


_GETCOPYOFOBJECTREQUEST = _descriptor.Descriptor(
  name='GetCopyOfObjectRequest',
  full_name='dataclay.communication.grpc.dataservice.GetCopyOfObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.GetCopyOfObjectRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.GetCopyOfObjectRequest.objectID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recursive', full_name='dataclay.communication.grpc.dataservice.GetCopyOfObjectRequest.recursive', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2499,
  serialized_end=2672,
)


_GETCOPYOFOBJECTRESPONSE = _descriptor.Descriptor(
  name='GetCopyOfObjectResponse',
  full_name='dataclay.communication.grpc.dataservice.GetCopyOfObjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ret', full_name='dataclay.communication.grpc.dataservice.GetCopyOfObjectResponse.ret', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.GetCopyOfObjectResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2675,
  serialized_end=2847,
)


_UPDATEOBJECTREQUEST = _descriptor.Descriptor(
  name='UpdateObjectRequest',
  full_name='dataclay.communication.grpc.dataservice.UpdateObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.UpdateObjectRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intoObjectID', full_name='dataclay.communication.grpc.dataservice.UpdateObjectRequest.intoObjectID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fromObject', full_name='dataclay.communication.grpc.dataservice.UpdateObjectRequest.fromObject', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2850,
  serialized_end=3091,
)


_GETOBJECTSREQUEST = _descriptor.Descriptor(
  name='GetObjectsRequest',
  full_name='dataclay.communication.grpc.dataservice.GetObjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.GetObjectsRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectIDS', full_name='dataclay.communication.grpc.dataservice.GetObjectsRequest.objectIDS', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recursive', full_name='dataclay.communication.grpc.dataservice.GetObjectsRequest.recursive', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='moving', full_name='dataclay.communication.grpc.dataservice.GetObjectsRequest.moving', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3094,
  serialized_end=3279,
)


_GETOBJECTSRESPONSE = _descriptor.Descriptor(
  name='GetObjectsResponse',
  full_name='dataclay.communication.grpc.dataservice.GetObjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='dataclay.communication.grpc.dataservice.GetObjectsResponse.objects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.GetObjectsResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3282,
  serialized_end=3452,
)


_GETFEDERATEDOBJECTSREQUEST = _descriptor.Descriptor(
  name='GetFederatedObjectsRequest',
  full_name='dataclay.communication.grpc.dataservice.GetFederatedObjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='extDataClayID', full_name='dataclay.communication.grpc.dataservice.GetFederatedObjectsRequest.extDataClayID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectIDS', full_name='dataclay.communication.grpc.dataservice.GetFederatedObjectsRequest.objectIDS', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3455,
  serialized_end=3627,
)


_GETFEDERATEDOBJECTSRESPONSE = _descriptor.Descriptor(
  name='GetFederatedObjectsResponse',
  full_name='dataclay.communication.grpc.dataservice.GetFederatedObjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='dataclay.communication.grpc.dataservice.GetFederatedObjectsResponse.objects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.GetFederatedObjectsResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3630,
  serialized_end=3809,
)


_FILTEROBJECTREQUEST = _descriptor.Descriptor(
  name='FilterObjectRequest',
  full_name='dataclay.communication.grpc.dataservice.FilterObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.FilterObjectRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.FilterObjectRequest.objectID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='dataclay.communication.grpc.dataservice.FilterObjectRequest.conditions', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3812,
  serialized_end=3983,
)


_FILTEROBJECTRESPONSE = _descriptor.Descriptor(
  name='FilterObjectResponse',
  full_name='dataclay.communication.grpc.dataservice.FilterObjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ret', full_name='dataclay.communication.grpc.dataservice.FilterObjectResponse.ret', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.FilterObjectResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3986,
  serialized_end=4155,
)


_GETREFERENCEDOBJECTIDSREQUEST = _descriptor.Descriptor(
  name='GetReferencedObjectIDsRequest',
  full_name='dataclay.communication.grpc.dataservice.GetReferencedObjectIDsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.GetReferencedObjectIDsRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectIDS', full_name='dataclay.communication.grpc.dataservice.GetReferencedObjectIDsRequest.objectIDS', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4158,
  serialized_end=4320,
)


_GETREFERENCEDOBJECTIDSRESPONSE = _descriptor.Descriptor(
  name='GetReferencedObjectIDsResponse',
  full_name='dataclay.communication.grpc.dataservice.GetReferencedObjectIDsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objectIDs', full_name='dataclay.communication.grpc.dataservice.GetReferencedObjectIDsResponse.objectIDs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.GetReferencedObjectIDsResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4323,
  serialized_end=4488,
)


_MAKEPERSISTENTREQUEST = _descriptor.Descriptor(
  name='MakePersistentRequest',
  full_name='dataclay.communication.grpc.dataservice.MakePersistentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.MakePersistentRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='dataclay.communication.grpc.dataservice.MakePersistentRequest.params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4491,
  serialized_end=4662,
)


_FEDERATEREQUEST = _descriptor.Descriptor(
  name='FederateRequest',
  full_name='dataclay.communication.grpc.dataservice.FederateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.FederateRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='dataclay.communication.grpc.dataservice.FederateRequest.params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4665,
  serialized_end=4830,
)


_UNFEDERATEREQUEST = _descriptor.Descriptor(
  name='UnfederateRequest',
  full_name='dataclay.communication.grpc.dataservice.UnfederateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.UnfederateRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectIDs', full_name='dataclay.communication.grpc.dataservice.UnfederateRequest.objectIDs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4833,
  serialized_end=4983,
)


_EXECUTEIMPLEMENTATIONREQUEST = _descriptor.Descriptor(
  name='ExecuteImplementationRequest',
  full_name='dataclay.communication.grpc.dataservice.ExecuteImplementationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.ExecuteImplementationRequest.objectID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='implementationID', full_name='dataclay.communication.grpc.dataservice.ExecuteImplementationRequest.implementationID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.ExecuteImplementationRequest.sessionID', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='dataclay.communication.grpc.dataservice.ExecuteImplementationRequest.params', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4986,
  serialized_end=5308,
)


_EXECUTEIMPLEMENTATIONRESPONSE = _descriptor.Descriptor(
  name='ExecuteImplementationResponse',
  full_name='dataclay.communication.grpc.dataservice.ExecuteImplementationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ret', full_name='dataclay.communication.grpc.dataservice.ExecuteImplementationResponse.ret', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.ExecuteImplementationResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5311,
  serialized_end=5489,
)


_SETNOTVOLATILEREQUEST = _descriptor.Descriptor(
  name='SetNotVolatileRequest',
  full_name='dataclay.communication.grpc.dataservice.SetNotVolatileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.SetNotVolatileRequest.objectID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storaDataSet', full_name='dataclay.communication.grpc.dataservice.SetNotVolatileRequest.storaDataSet', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5492,
  serialized_end=5648,
)


_NEWVERSIONREQUEST = _descriptor.Descriptor(
  name='NewVersionRequest',
  full_name='dataclay.communication.grpc.dataservice.NewVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.NewVersionRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.NewVersionRequest.objectID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadataInfo', full_name='dataclay.communication.grpc.dataservice.NewVersionRequest.metadataInfo', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5651,
  serialized_end=5822,
)


_NEWVERSIONRESPONSE_VERSIONEDIDSENTRY = _descriptor.Descriptor(
  name='VersionedIDsEntry',
  full_name='dataclay.communication.grpc.dataservice.NewVersionResponse.VersionedIDsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.NewVersionResponse.VersionedIDsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.NewVersionResponse.VersionedIDsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6080,
  serialized_end=6131,
)

_NEWVERSIONRESPONSE = _descriptor.Descriptor(
  name='NewVersionResponse',
  full_name='dataclay.communication.grpc.dataservice.NewVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.NewVersionResponse.objectID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionedIDs', full_name='dataclay.communication.grpc.dataservice.NewVersionResponse.versionedIDs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.NewVersionResponse.excInfo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_NEWVERSIONRESPONSE_VERSIONEDIDSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5825,
  serialized_end=6131,
)


_CONSOLIDATEVERSIONREQUEST = _descriptor.Descriptor(
  name='ConsolidateVersionRequest',
  full_name='dataclay.communication.grpc.dataservice.ConsolidateVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.ConsolidateVersionRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versionInfo', full_name='dataclay.communication.grpc.dataservice.ConsolidateVersionRequest.versionInfo', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6133,
  serialized_end=6247,
)


_UPSERTOBJECTSREQUEST = _descriptor.Descriptor(
  name='UpsertObjectsRequest',
  full_name='dataclay.communication.grpc.dataservice.UpsertObjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.UpsertObjectsRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytesUpdate', full_name='dataclay.communication.grpc.dataservice.UpsertObjectsRequest.bytesUpdate', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6250,
  serialized_end=6424,
)


_NEWREPLICAREQUEST = _descriptor.Descriptor(
  name='NewReplicaRequest',
  full_name='dataclay.communication.grpc.dataservice.NewReplicaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.NewReplicaRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.NewReplicaRequest.objectID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recursive', full_name='dataclay.communication.grpc.dataservice.NewReplicaRequest.recursive', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6427,
  serialized_end=6595,
)


_NEWREPLICARESPONSE = _descriptor.Descriptor(
  name='NewReplicaResponse',
  full_name='dataclay.communication.grpc.dataservice.NewReplicaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='replicatedIDs', full_name='dataclay.communication.grpc.dataservice.NewReplicaResponse.replicatedIDs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.NewReplicaResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6598,
  serialized_end=6755,
)


_MOVEOBJECTSREQUEST = _descriptor.Descriptor(
  name='MoveObjectsRequest',
  full_name='dataclay.communication.grpc.dataservice.MoveObjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.MoveObjectsRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.MoveObjectsRequest.objectID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destLocID', full_name='dataclay.communication.grpc.dataservice.MoveObjectsRequest.destLocID', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recursive', full_name='dataclay.communication.grpc.dataservice.MoveObjectsRequest.recursive', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6758,
  serialized_end=7006,
)


_MOVEOBJECTSRESPONSE = _descriptor.Descriptor(
  name='MoveObjectsResponse',
  full_name='dataclay.communication.grpc.dataservice.MoveObjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='movedObjects', full_name='dataclay.communication.grpc.dataservice.MoveObjectsResponse.movedObjects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.MoveObjectsResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7009,
  serialized_end=7166,
)


_REMOVEOBJECTSREQUEST = _descriptor.Descriptor(
  name='RemoveObjectsRequest',
  full_name='dataclay.communication.grpc.dataservice.RemoveObjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.RemoveObjectsRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectIDs', full_name='dataclay.communication.grpc.dataservice.RemoveObjectsRequest.objectIDs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recursive', full_name='dataclay.communication.grpc.dataservice.RemoveObjectsRequest.recursive', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='moving', full_name='dataclay.communication.grpc.dataservice.RemoveObjectsRequest.moving', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newHint', full_name='dataclay.communication.grpc.dataservice.RemoveObjectsRequest.newHint', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7169,
  serialized_end=7434,
)


_JUMPMAPTHREADMSG_JUMPMAPTHREADENTRY = _descriptor.Descriptor(
  name='JumpMapThreadEntry',
  full_name='dataclay.communication.grpc.dataservice.JumpMapThreadMsg.JumpMapThreadEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.JumpMapThreadMsg.JumpMapThreadEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.JumpMapThreadMsg.JumpMapThreadEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7558,
  serialized_end=7610,
)

_JUMPMAPTHREADMSG = _descriptor.Descriptor(
  name='JumpMapThreadMsg',
  full_name='dataclay.communication.grpc.dataservice.JumpMapThreadMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jumpMapThread', full_name='dataclay.communication.grpc.dataservice.JumpMapThreadMsg.jumpMapThread', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_JUMPMAPTHREADMSG_JUMPMAPTHREADENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7437,
  serialized_end=7610,
)


_REMOVEOBJECTSRESPONSE_REMOVEDOBJECTSENTRY = _descriptor.Descriptor(
  name='RemovedObjectsEntry',
  full_name='dataclay.communication.grpc.dataservice.RemoveObjectsResponse.RemovedObjectsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.RemoveObjectsResponse.RemovedObjectsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.RemoveObjectsResponse.RemovedObjectsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7814,
  serialized_end=7867,
)

_REMOVEOBJECTSRESPONSE = _descriptor.Descriptor(
  name='RemoveObjectsResponse',
  full_name='dataclay.communication.grpc.dataservice.RemoveObjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='removedObjects', full_name='dataclay.communication.grpc.dataservice.RemoveObjectsResponse.removedObjects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.RemoveObjectsResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REMOVEOBJECTSRESPONSE_REMOVEDOBJECTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7613,
  serialized_end=7867,
)


_MIGRATEOBJECTSREQUEST_DESTSTORAGELOCSENTRY = _descriptor.Descriptor(
  name='DestStorageLocsEntry',
  full_name='dataclay.communication.grpc.dataservice.MigrateObjectsRequest.DestStorageLocsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.MigrateObjectsRequest.DestStorageLocsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.MigrateObjectsRequest.DestStorageLocsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8005,
  serialized_end=8059,
)

_MIGRATEOBJECTSREQUEST = _descriptor.Descriptor(
  name='MigrateObjectsRequest',
  full_name='dataclay.communication.grpc.dataservice.MigrateObjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='destStorageLocs', full_name='dataclay.communication.grpc.dataservice.MigrateObjectsRequest.destStorageLocs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MIGRATEOBJECTSREQUEST_DESTSTORAGELOCSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7870,
  serialized_end=8059,
)


_MIGRATEDOBJECTS = _descriptor.Descriptor(
  name='MigratedObjects',
  full_name='dataclay.communication.grpc.dataservice.MigratedObjects',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objs', full_name='dataclay.communication.grpc.dataservice.MigratedObjects.objs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8061,
  serialized_end=8138,
)


_MIGRATEOBJECTSRESPONSE_MIGRATEDOBJSENTRY = _descriptor.Descriptor(
  name='MigratedObjsEntry',
  full_name='dataclay.communication.grpc.dataservice.MigrateObjectsResponse.MigratedObjsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.MigrateObjectsResponse.MigratedObjsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.MigrateObjectsResponse.MigratedObjsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8423,
  serialized_end=8532,
)

_MIGRATEOBJECTSRESPONSE = _descriptor.Descriptor(
  name='MigrateObjectsResponse',
  full_name='dataclay.communication.grpc.dataservice.MigrateObjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='migratedObjs', full_name='dataclay.communication.grpc.dataservice.MigrateObjectsResponse.migratedObjs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonMigratedObjs', full_name='dataclay.communication.grpc.dataservice.MigrateObjectsResponse.nonMigratedObjs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.MigrateObjectsResponse.excInfo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MIGRATEOBJECTSRESPONSE_MIGRATEDOBJSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8141,
  serialized_end=8532,
)


_ACTIVATETRACINGREQUEST = _descriptor.Descriptor(
  name='ActivateTracingRequest',
  full_name='dataclay.communication.grpc.dataservice.ActivateTracingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='taskid', full_name='dataclay.communication.grpc.dataservice.ActivateTracingRequest.taskid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8534,
  serialized_end=8574,
)


_CLOSESESSIONINDSREQUEST = _descriptor.Descriptor(
  name='CloseSessionInDSRequest',
  full_name='dataclay.communication.grpc.dataservice.CloseSessionInDSRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionID', full_name='dataclay.communication.grpc.dataservice.CloseSessionInDSRequest.sessionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8576,
  serialized_end=8667,
)


_DISKCOLLECTREQUEST_REFSTOUPDATEENTRY = _descriptor.Descriptor(
  name='RefsToUpdateEntry',
  full_name='dataclay.communication.grpc.dataservice.DiskCollectRequest.RefsToUpdateEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.DiskCollectRequest.RefsToUpdateEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.DiskCollectRequest.RefsToUpdateEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9018,
  serialized_end=9069,
)

_DISKCOLLECTREQUEST = _descriptor.Descriptor(
  name='DiskCollectRequest',
  full_name='dataclay.communication.grpc.dataservice.DiskCollectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='epochNodeID', full_name='dataclay.communication.grpc.dataservice.DiskCollectRequest.epochNodeID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ringPath', full_name='dataclay.communication.grpc.dataservice.DiskCollectRequest.ringPath', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='candidates', full_name='dataclay.communication.grpc.dataservice.DiskCollectRequest.candidates', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refsToUpdate', full_name='dataclay.communication.grpc.dataservice.DiskCollectRequest.refsToUpdate', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DISKCOLLECTREQUEST_REFSTOUPDATEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8670,
  serialized_end=9069,
)


_GETCLASSIDFROMOBJECTINMEMORYREQUEST = _descriptor.Descriptor(
  name='GetClassIDFromObjectInMemoryRequest',
  full_name='dataclay.communication.grpc.dataservice.GetClassIDFromObjectInMemoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.GetClassIDFromObjectInMemoryRequest.objectID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9071,
  serialized_end=9172,
)


_GETCLASSIDFROMOBJECTINMEMORYRESPONSE = _descriptor.Descriptor(
  name='GetClassIDFromObjectInMemoryResponse',
  full_name='dataclay.communication.grpc.dataservice.GetClassIDFromObjectInMemoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='classID', full_name='dataclay.communication.grpc.dataservice.GetClassIDFromObjectInMemoryResponse.classID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.GetClassIDFromObjectInMemoryResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9175,
  serialized_end=9347,
)


_STORETODBREQUEST = _descriptor.Descriptor(
  name='StoreToDBRequest',
  full_name='dataclay.communication.grpc.dataservice.StoreToDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executionEnvironmentID', full_name='dataclay.communication.grpc.dataservice.StoreToDBRequest.executionEnvironmentID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.StoreToDBRequest.objectID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objBytes', full_name='dataclay.communication.grpc.dataservice.StoreToDBRequest.objBytes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9350,
  serialized_end=9542,
)


_GETFROMDBREQUEST = _descriptor.Descriptor(
  name='GetFromDBRequest',
  full_name='dataclay.communication.grpc.dataservice.GetFromDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executionEnvironmentID', full_name='dataclay.communication.grpc.dataservice.GetFromDBRequest.executionEnvironmentID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.GetFromDBRequest.objectID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9545,
  serialized_end=9719,
)


_GETFROMDBRESPONSE = _descriptor.Descriptor(
  name='GetFromDBResponse',
  full_name='dataclay.communication.grpc.dataservice.GetFromDBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objBytes', full_name='dataclay.communication.grpc.dataservice.GetFromDBResponse.objBytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.GetFromDBResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9721,
  serialized_end=9826,
)


_UPDATETODBREQUEST = _descriptor.Descriptor(
  name='UpdateToDBRequest',
  full_name='dataclay.communication.grpc.dataservice.UpdateToDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executionEnvironmentID', full_name='dataclay.communication.grpc.dataservice.UpdateToDBRequest.executionEnvironmentID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.UpdateToDBRequest.objectID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objBytes', full_name='dataclay.communication.grpc.dataservice.UpdateToDBRequest.objBytes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dirty', full_name='dataclay.communication.grpc.dataservice.UpdateToDBRequest.dirty', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9829,
  serialized_end=10037,
)


_DELETETODBREQUEST = _descriptor.Descriptor(
  name='DeleteToDBRequest',
  full_name='dataclay.communication.grpc.dataservice.DeleteToDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executionEnvironmentID', full_name='dataclay.communication.grpc.dataservice.DeleteToDBRequest.executionEnvironmentID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.DeleteToDBRequest.objectID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10040,
  serialized_end=10215,
)


_UPDATEREFSREQUEST_REFSTOUPDATEENTRY = _descriptor.Descriptor(
  name='RefsToUpdateEntry',
  full_name='dataclay.communication.grpc.dataservice.UpdateRefsRequest.RefsToUpdateEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataclay.communication.grpc.dataservice.UpdateRefsRequest.RefsToUpdateEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataclay.communication.grpc.dataservice.UpdateRefsRequest.RefsToUpdateEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9018,
  serialized_end=9069,
)

_UPDATEREFSREQUEST = _descriptor.Descriptor(
  name='UpdateRefsRequest',
  full_name='dataclay.communication.grpc.dataservice.UpdateRefsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='refsToUpdate', full_name='dataclay.communication.grpc.dataservice.UpdateRefsRequest.refsToUpdate', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEREFSREQUEST_REFSTOUPDATEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10218,
  serialized_end=10390,
)


_GETRETAINEDREFERENCESRESPONSE = _descriptor.Descriptor(
  name='GetRetainedReferencesResponse',
  full_name='dataclay.communication.grpc.dataservice.GetRetainedReferencesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='retainedReferences', full_name='dataclay.communication.grpc.dataservice.GetRetainedReferencesResponse.retainedReferences', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.GetRetainedReferencesResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10393,
  serialized_end=10566,
)


_EXISTSREQUEST = _descriptor.Descriptor(
  name='ExistsRequest',
  full_name='dataclay.communication.grpc.dataservice.ExistsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.ExistsRequest.objectID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10568,
  serialized_end=10647,
)


_EXISTSRESPONSE = _descriptor.Descriptor(
  name='ExistsResponse',
  full_name='dataclay.communication.grpc.dataservice.ExistsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exists', full_name='dataclay.communication.grpc.dataservice.ExistsResponse.exists', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.ExistsResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10649,
  serialized_end=10749,
)


_EXISTSINDBREQUEST = _descriptor.Descriptor(
  name='ExistsInDBRequest',
  full_name='dataclay.communication.grpc.dataservice.ExistsInDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objectID', full_name='dataclay.communication.grpc.dataservice.ExistsInDBRequest.objectID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10751,
  serialized_end=10834,
)


_EXISTSINDBRESPONSE = _descriptor.Descriptor(
  name='ExistsInDBResponse',
  full_name='dataclay.communication.grpc.dataservice.ExistsInDBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exists', full_name='dataclay.communication.grpc.dataservice.ExistsInDBResponse.exists', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excInfo', full_name='dataclay.communication.grpc.dataservice.ExistsInDBResponse.excInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10836,
  serialized_end=10940,
)

_INITBACKENDIDREQUEST.fields_by_name['backendID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._STORAGELOCATIONID
_ASSOCIATEEXECUTIONENVIRONMENTREQUEST.fields_by_name['executionEnvironmentID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXECUTIONENVIRONMENTID
_DEPLOYMETACLASSESREQUEST_DEPLOYMENTPACKENTRY.containing_type = _DEPLOYMETACLASSESREQUEST
_DEPLOYMETACLASSESREQUEST.fields_by_name['deploymentPack'].message_type = _DEPLOYMETACLASSESREQUEST_DEPLOYMENTPACKENTRY
_DEPLOYCLASSESREQUEST_CLASSESTODEPLOYENTRY.containing_type = _DEPLOYCLASSESREQUEST
_DEPLOYCLASSESREQUEST_CLASSIDSENTRY.fields_by_name['value'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._METACLASSID
_DEPLOYCLASSESREQUEST_CLASSIDSENTRY.containing_type = _DEPLOYCLASSESREQUEST
_DEPLOYCLASSESREQUEST_ASPECTSENTRY.containing_type = _DEPLOYCLASSESREQUEST
_DEPLOYCLASSESREQUEST_YAMLSENTRY.containing_type = _DEPLOYCLASSESREQUEST
_DEPLOYCLASSESREQUEST.fields_by_name['classesToDeploy'].message_type = _DEPLOYCLASSESREQUEST_CLASSESTODEPLOYENTRY
_DEPLOYCLASSESREQUEST.fields_by_name['classIds'].message_type = _DEPLOYCLASSESREQUEST_CLASSIDSENTRY
_DEPLOYCLASSESREQUEST.fields_by_name['aspects'].message_type = _DEPLOYCLASSESREQUEST_ASPECTSENTRY
_DEPLOYCLASSESREQUEST.fields_by_name['yamls'].message_type = _DEPLOYCLASSESREQUEST_YAMLSENTRY
_NEWPERSISTENTINSTANCEREQUEST_IFACEBITMAPSENTRY.containing_type = _NEWPERSISTENTINSTANCEREQUEST
_NEWPERSISTENTINSTANCEREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_NEWPERSISTENTINSTANCEREQUEST.fields_by_name['classID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._METACLASSID
_NEWPERSISTENTINSTANCEREQUEST.fields_by_name['implementationID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._IMPLEMENTATIONID
_NEWPERSISTENTINSTANCEREQUEST.fields_by_name['ifaceBitMaps'].message_type = _NEWPERSISTENTINSTANCEREQUEST_IFACEBITMAPSENTRY
_NEWPERSISTENTINSTANCEREQUEST.fields_by_name['params'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SERIALIZEDPARAMETERSORRETURN
_NEWPERSISTENTINSTANCERESPONSE.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_NEWPERSISTENTINSTANCERESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_STOREOBJECTSREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_STOREOBJECTSREQUEST.fields_by_name['objects'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTWITHDATAPARAMORRETURN
_STOREOBJECTSREQUEST.fields_by_name['idsWithAlias'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_NEWMETADATAREQUEST_MDINFOSENTRY.containing_type = _NEWMETADATAREQUEST
_NEWMETADATAREQUEST.fields_by_name['mdInfos'].message_type = _NEWMETADATAREQUEST_MDINFOSENTRY
_GETCOPYOFOBJECTREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_GETCOPYOFOBJECTREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_GETCOPYOFOBJECTRESPONSE.fields_by_name['ret'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SERIALIZEDPARAMETERSORRETURN
_GETCOPYOFOBJECTRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_UPDATEOBJECTREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_UPDATEOBJECTREQUEST.fields_by_name['intoObjectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_UPDATEOBJECTREQUEST.fields_by_name['fromObject'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SERIALIZEDPARAMETERSORRETURN
_GETOBJECTSREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_GETOBJECTSREQUEST.fields_by_name['objectIDS'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_GETOBJECTSRESPONSE.fields_by_name['objects'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTWITHDATAPARAMORRETURN
_GETOBJECTSRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_GETFEDERATEDOBJECTSREQUEST.fields_by_name['extDataClayID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._DATACLAYINSTANCEID
_GETFEDERATEDOBJECTSREQUEST.fields_by_name['objectIDS'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_GETFEDERATEDOBJECTSRESPONSE.fields_by_name['objects'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTWITHDATAPARAMORRETURN
_GETFEDERATEDOBJECTSRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_FILTEROBJECTREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_FILTEROBJECTREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_FILTEROBJECTRESPONSE.fields_by_name['ret'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SERIALIZEDPARAMETERSORRETURN
_FILTEROBJECTRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_GETREFERENCEDOBJECTIDSREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_GETREFERENCEDOBJECTIDSREQUEST.fields_by_name['objectIDS'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_GETREFERENCEDOBJECTIDSRESPONSE.fields_by_name['objectIDs'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_GETREFERENCEDOBJECTIDSRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_MAKEPERSISTENTREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_MAKEPERSISTENTREQUEST.fields_by_name['params'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SERIALIZEDPARAMETERSORRETURN
_FEDERATEREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_FEDERATEREQUEST.fields_by_name['params'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SERIALIZEDPARAMETERSORRETURN
_UNFEDERATEREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_UNFEDERATEREQUEST.fields_by_name['objectIDs'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_EXECUTEIMPLEMENTATIONREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_EXECUTEIMPLEMENTATIONREQUEST.fields_by_name['implementationID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._IMPLEMENTATIONID
_EXECUTEIMPLEMENTATIONREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_EXECUTEIMPLEMENTATIONREQUEST.fields_by_name['params'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SERIALIZEDPARAMETERSORRETURN
_EXECUTEIMPLEMENTATIONRESPONSE.fields_by_name['ret'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SERIALIZEDPARAMETERSORRETURN
_EXECUTEIMPLEMENTATIONRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_SETNOTVOLATILEREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_SETNOTVOLATILEREQUEST.fields_by_name['storaDataSet'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._DATASETID
_NEWVERSIONREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_NEWVERSIONREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_NEWVERSIONRESPONSE_VERSIONEDIDSENTRY.containing_type = _NEWVERSIONRESPONSE
_NEWVERSIONRESPONSE.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_NEWVERSIONRESPONSE.fields_by_name['versionedIDs'].message_type = _NEWVERSIONRESPONSE_VERSIONEDIDSENTRY
_NEWVERSIONRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_CONSOLIDATEVERSIONREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_UPSERTOBJECTSREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_UPSERTOBJECTSREQUEST.fields_by_name['bytesUpdate'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTWITHDATAPARAMORRETURN
_NEWREPLICAREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_NEWREPLICAREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_NEWREPLICARESPONSE.fields_by_name['replicatedIDs'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_NEWREPLICARESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_MOVEOBJECTSREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_MOVEOBJECTSREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_MOVEOBJECTSREQUEST.fields_by_name['destLocID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXECUTIONENVIRONMENTID
_MOVEOBJECTSRESPONSE.fields_by_name['movedObjects'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_MOVEOBJECTSRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_REMOVEOBJECTSREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_REMOVEOBJECTSREQUEST.fields_by_name['objectIDs'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_REMOVEOBJECTSREQUEST.fields_by_name['newHint'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXECUTIONENVIRONMENTID
_JUMPMAPTHREADMSG_JUMPMAPTHREADENTRY.containing_type = _JUMPMAPTHREADMSG
_JUMPMAPTHREADMSG.fields_by_name['jumpMapThread'].message_type = _JUMPMAPTHREADMSG_JUMPMAPTHREADENTRY
_REMOVEOBJECTSRESPONSE_REMOVEDOBJECTSENTRY.containing_type = _REMOVEOBJECTSRESPONSE
_REMOVEOBJECTSRESPONSE.fields_by_name['removedObjects'].message_type = _REMOVEOBJECTSRESPONSE_REMOVEDOBJECTSENTRY
_REMOVEOBJECTSRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_MIGRATEOBJECTSREQUEST_DESTSTORAGELOCSENTRY.containing_type = _MIGRATEOBJECTSREQUEST
_MIGRATEOBJECTSREQUEST.fields_by_name['destStorageLocs'].message_type = _MIGRATEOBJECTSREQUEST_DESTSTORAGELOCSENTRY
_MIGRATEDOBJECTS.fields_by_name['objs'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_MIGRATEOBJECTSRESPONSE_MIGRATEDOBJSENTRY.fields_by_name['value'].message_type = _MIGRATEDOBJECTS
_MIGRATEOBJECTSRESPONSE_MIGRATEDOBJSENTRY.containing_type = _MIGRATEOBJECTSRESPONSE
_MIGRATEOBJECTSRESPONSE.fields_by_name['migratedObjs'].message_type = _MIGRATEOBJECTSRESPONSE_MIGRATEDOBJSENTRY
_MIGRATEOBJECTSRESPONSE.fields_by_name['nonMigratedObjs'].message_type = _MIGRATEDOBJECTS
_MIGRATEOBJECTSRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_CLOSESESSIONINDSREQUEST.fields_by_name['sessionID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._SESSIONID
_DISKCOLLECTREQUEST_REFSTOUPDATEENTRY.containing_type = _DISKCOLLECTREQUEST
_DISKCOLLECTREQUEST.fields_by_name['epochNodeID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXECUTIONENVIRONMENTID
_DISKCOLLECTREQUEST.fields_by_name['ringPath'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXECUTIONENVIRONMENTID
_DISKCOLLECTREQUEST.fields_by_name['candidates'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_DISKCOLLECTREQUEST.fields_by_name['refsToUpdate'].message_type = _DISKCOLLECTREQUEST_REFSTOUPDATEENTRY
_GETCLASSIDFROMOBJECTINMEMORYREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_GETCLASSIDFROMOBJECTINMEMORYRESPONSE.fields_by_name['classID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._METACLASSID
_GETCLASSIDFROMOBJECTINMEMORYRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_STORETODBREQUEST.fields_by_name['executionEnvironmentID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXECUTIONENVIRONMENTID
_STORETODBREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_GETFROMDBREQUEST.fields_by_name['executionEnvironmentID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXECUTIONENVIRONMENTID
_GETFROMDBREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_GETFROMDBRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_UPDATETODBREQUEST.fields_by_name['executionEnvironmentID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXECUTIONENVIRONMENTID
_UPDATETODBREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_DELETETODBREQUEST.fields_by_name['executionEnvironmentID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXECUTIONENVIRONMENTID
_DELETETODBREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_UPDATEREFSREQUEST_REFSTOUPDATEENTRY.containing_type = _UPDATEREFSREQUEST
_UPDATEREFSREQUEST.fields_by_name['refsToUpdate'].message_type = _UPDATEREFSREQUEST_REFSTOUPDATEENTRY
_GETRETAINEDREFERENCESRESPONSE.fields_by_name['retainedReferences'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_GETRETAINEDREFERENCESRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_EXISTSREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_EXISTSRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
_EXISTSINDBREQUEST.fields_by_name['objectID'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._OBJECTID
_EXISTSINDBRESPONSE.fields_by_name['excInfo'].message_type = dataclay_dot_communication_dot_grpc_dot_messages_dot_common_dot_common__messages__pb2._EXCEPTIONINFO
DESCRIPTOR.message_types_by_name['InitBackendIDRequest'] = _INITBACKENDIDREQUEST
DESCRIPTOR.message_types_by_name['AssociateExecutionEnvironmentRequest'] = _ASSOCIATEEXECUTIONENVIRONMENTREQUEST
DESCRIPTOR.message_types_by_name['DeployMetaClassesRequest'] = _DEPLOYMETACLASSESREQUEST
DESCRIPTOR.message_types_by_name['DeployClassesRequest'] = _DEPLOYCLASSESREQUEST
DESCRIPTOR.message_types_by_name['EnrichClassRequest'] = _ENRICHCLASSREQUEST
DESCRIPTOR.message_types_by_name['NewPersistentInstanceRequest'] = _NEWPERSISTENTINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['NewPersistentInstanceResponse'] = _NEWPERSISTENTINSTANCERESPONSE
DESCRIPTOR.message_types_by_name['StoreObjectsRequest'] = _STOREOBJECTSREQUEST
DESCRIPTOR.message_types_by_name['NewMetaDataRequest'] = _NEWMETADATAREQUEST
DESCRIPTOR.message_types_by_name['GetCopyOfObjectRequest'] = _GETCOPYOFOBJECTREQUEST
DESCRIPTOR.message_types_by_name['GetCopyOfObjectResponse'] = _GETCOPYOFOBJECTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateObjectRequest'] = _UPDATEOBJECTREQUEST
DESCRIPTOR.message_types_by_name['GetObjectsRequest'] = _GETOBJECTSREQUEST
DESCRIPTOR.message_types_by_name['GetObjectsResponse'] = _GETOBJECTSRESPONSE
DESCRIPTOR.message_types_by_name['GetFederatedObjectsRequest'] = _GETFEDERATEDOBJECTSREQUEST
DESCRIPTOR.message_types_by_name['GetFederatedObjectsResponse'] = _GETFEDERATEDOBJECTSRESPONSE
DESCRIPTOR.message_types_by_name['FilterObjectRequest'] = _FILTEROBJECTREQUEST
DESCRIPTOR.message_types_by_name['FilterObjectResponse'] = _FILTEROBJECTRESPONSE
DESCRIPTOR.message_types_by_name['GetReferencedObjectIDsRequest'] = _GETREFERENCEDOBJECTIDSREQUEST
DESCRIPTOR.message_types_by_name['GetReferencedObjectIDsResponse'] = _GETREFERENCEDOBJECTIDSRESPONSE
DESCRIPTOR.message_types_by_name['MakePersistentRequest'] = _MAKEPERSISTENTREQUEST
DESCRIPTOR.message_types_by_name['FederateRequest'] = _FEDERATEREQUEST
DESCRIPTOR.message_types_by_name['UnfederateRequest'] = _UNFEDERATEREQUEST
DESCRIPTOR.message_types_by_name['ExecuteImplementationRequest'] = _EXECUTEIMPLEMENTATIONREQUEST
DESCRIPTOR.message_types_by_name['ExecuteImplementationResponse'] = _EXECUTEIMPLEMENTATIONRESPONSE
DESCRIPTOR.message_types_by_name['SetNotVolatileRequest'] = _SETNOTVOLATILEREQUEST
DESCRIPTOR.message_types_by_name['NewVersionRequest'] = _NEWVERSIONREQUEST
DESCRIPTOR.message_types_by_name['NewVersionResponse'] = _NEWVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['ConsolidateVersionRequest'] = _CONSOLIDATEVERSIONREQUEST
DESCRIPTOR.message_types_by_name['UpsertObjectsRequest'] = _UPSERTOBJECTSREQUEST
DESCRIPTOR.message_types_by_name['NewReplicaRequest'] = _NEWREPLICAREQUEST
DESCRIPTOR.message_types_by_name['NewReplicaResponse'] = _NEWREPLICARESPONSE
DESCRIPTOR.message_types_by_name['MoveObjectsRequest'] = _MOVEOBJECTSREQUEST
DESCRIPTOR.message_types_by_name['MoveObjectsResponse'] = _MOVEOBJECTSRESPONSE
DESCRIPTOR.message_types_by_name['RemoveObjectsRequest'] = _REMOVEOBJECTSREQUEST
DESCRIPTOR.message_types_by_name['JumpMapThreadMsg'] = _JUMPMAPTHREADMSG
DESCRIPTOR.message_types_by_name['RemoveObjectsResponse'] = _REMOVEOBJECTSRESPONSE
DESCRIPTOR.message_types_by_name['MigrateObjectsRequest'] = _MIGRATEOBJECTSREQUEST
DESCRIPTOR.message_types_by_name['MigratedObjects'] = _MIGRATEDOBJECTS
DESCRIPTOR.message_types_by_name['MigrateObjectsResponse'] = _MIGRATEOBJECTSRESPONSE
DESCRIPTOR.message_types_by_name['ActivateTracingRequest'] = _ACTIVATETRACINGREQUEST
DESCRIPTOR.message_types_by_name['CloseSessionInDSRequest'] = _CLOSESESSIONINDSREQUEST
DESCRIPTOR.message_types_by_name['DiskCollectRequest'] = _DISKCOLLECTREQUEST
DESCRIPTOR.message_types_by_name['GetClassIDFromObjectInMemoryRequest'] = _GETCLASSIDFROMOBJECTINMEMORYREQUEST
DESCRIPTOR.message_types_by_name['GetClassIDFromObjectInMemoryResponse'] = _GETCLASSIDFROMOBJECTINMEMORYRESPONSE
DESCRIPTOR.message_types_by_name['StoreToDBRequest'] = _STORETODBREQUEST
DESCRIPTOR.message_types_by_name['GetFromDBRequest'] = _GETFROMDBREQUEST
DESCRIPTOR.message_types_by_name['GetFromDBResponse'] = _GETFROMDBRESPONSE
DESCRIPTOR.message_types_by_name['UpdateToDBRequest'] = _UPDATETODBREQUEST
DESCRIPTOR.message_types_by_name['DeleteToDBRequest'] = _DELETETODBREQUEST
DESCRIPTOR.message_types_by_name['UpdateRefsRequest'] = _UPDATEREFSREQUEST
DESCRIPTOR.message_types_by_name['GetRetainedReferencesResponse'] = _GETRETAINEDREFERENCESRESPONSE
DESCRIPTOR.message_types_by_name['ExistsRequest'] = _EXISTSREQUEST
DESCRIPTOR.message_types_by_name['ExistsResponse'] = _EXISTSRESPONSE
DESCRIPTOR.message_types_by_name['ExistsInDBRequest'] = _EXISTSINDBREQUEST
DESCRIPTOR.message_types_by_name['ExistsInDBResponse'] = _EXISTSINDBRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InitBackendIDRequest = _reflection.GeneratedProtocolMessageType('InitBackendIDRequest', (_message.Message,), dict(
  DESCRIPTOR = _INITBACKENDIDREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.InitBackendIDRequest)
  ))
_sym_db.RegisterMessage(InitBackendIDRequest)

AssociateExecutionEnvironmentRequest = _reflection.GeneratedProtocolMessageType('AssociateExecutionEnvironmentRequest', (_message.Message,), dict(
  DESCRIPTOR = _ASSOCIATEEXECUTIONENVIRONMENTREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.AssociateExecutionEnvironmentRequest)
  ))
_sym_db.RegisterMessage(AssociateExecutionEnvironmentRequest)

DeployMetaClassesRequest = _reflection.GeneratedProtocolMessageType('DeployMetaClassesRequest', (_message.Message,), dict(

  DeploymentPackEntry = _reflection.GeneratedProtocolMessageType('DeploymentPackEntry', (_message.Message,), dict(
    DESCRIPTOR = _DEPLOYMETACLASSESREQUEST_DEPLOYMENTPACKENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.DeployMetaClassesRequest.DeploymentPackEntry)
    ))
  ,
  DESCRIPTOR = _DEPLOYMETACLASSESREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.DeployMetaClassesRequest)
  ))
_sym_db.RegisterMessage(DeployMetaClassesRequest)
_sym_db.RegisterMessage(DeployMetaClassesRequest.DeploymentPackEntry)

DeployClassesRequest = _reflection.GeneratedProtocolMessageType('DeployClassesRequest', (_message.Message,), dict(

  ClassesToDeployEntry = _reflection.GeneratedProtocolMessageType('ClassesToDeployEntry', (_message.Message,), dict(
    DESCRIPTOR = _DEPLOYCLASSESREQUEST_CLASSESTODEPLOYENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.DeployClassesRequest.ClassesToDeployEntry)
    ))
  ,

  ClassIdsEntry = _reflection.GeneratedProtocolMessageType('ClassIdsEntry', (_message.Message,), dict(
    DESCRIPTOR = _DEPLOYCLASSESREQUEST_CLASSIDSENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.DeployClassesRequest.ClassIdsEntry)
    ))
  ,

  AspectsEntry = _reflection.GeneratedProtocolMessageType('AspectsEntry', (_message.Message,), dict(
    DESCRIPTOR = _DEPLOYCLASSESREQUEST_ASPECTSENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.DeployClassesRequest.AspectsEntry)
    ))
  ,

  YamlsEntry = _reflection.GeneratedProtocolMessageType('YamlsEntry', (_message.Message,), dict(
    DESCRIPTOR = _DEPLOYCLASSESREQUEST_YAMLSENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.DeployClassesRequest.YamlsEntry)
    ))
  ,
  DESCRIPTOR = _DEPLOYCLASSESREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.DeployClassesRequest)
  ))
_sym_db.RegisterMessage(DeployClassesRequest)
_sym_db.RegisterMessage(DeployClassesRequest.ClassesToDeployEntry)
_sym_db.RegisterMessage(DeployClassesRequest.ClassIdsEntry)
_sym_db.RegisterMessage(DeployClassesRequest.AspectsEntry)
_sym_db.RegisterMessage(DeployClassesRequest.YamlsEntry)

EnrichClassRequest = _reflection.GeneratedProtocolMessageType('EnrichClassRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENRICHCLASSREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.EnrichClassRequest)
  ))
_sym_db.RegisterMessage(EnrichClassRequest)

NewPersistentInstanceRequest = _reflection.GeneratedProtocolMessageType('NewPersistentInstanceRequest', (_message.Message,), dict(

  IfaceBitMapsEntry = _reflection.GeneratedProtocolMessageType('IfaceBitMapsEntry', (_message.Message,), dict(
    DESCRIPTOR = _NEWPERSISTENTINSTANCEREQUEST_IFACEBITMAPSENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.NewPersistentInstanceRequest.IfaceBitMapsEntry)
    ))
  ,
  DESCRIPTOR = _NEWPERSISTENTINSTANCEREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.NewPersistentInstanceRequest)
  ))
_sym_db.RegisterMessage(NewPersistentInstanceRequest)
_sym_db.RegisterMessage(NewPersistentInstanceRequest.IfaceBitMapsEntry)

NewPersistentInstanceResponse = _reflection.GeneratedProtocolMessageType('NewPersistentInstanceResponse', (_message.Message,), dict(
  DESCRIPTOR = _NEWPERSISTENTINSTANCERESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.NewPersistentInstanceResponse)
  ))
_sym_db.RegisterMessage(NewPersistentInstanceResponse)

StoreObjectsRequest = _reflection.GeneratedProtocolMessageType('StoreObjectsRequest', (_message.Message,), dict(
  DESCRIPTOR = _STOREOBJECTSREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.StoreObjectsRequest)
  ))
_sym_db.RegisterMessage(StoreObjectsRequest)

NewMetaDataRequest = _reflection.GeneratedProtocolMessageType('NewMetaDataRequest', (_message.Message,), dict(

  MdInfosEntry = _reflection.GeneratedProtocolMessageType('MdInfosEntry', (_message.Message,), dict(
    DESCRIPTOR = _NEWMETADATAREQUEST_MDINFOSENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.NewMetaDataRequest.MdInfosEntry)
    ))
  ,
  DESCRIPTOR = _NEWMETADATAREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.NewMetaDataRequest)
  ))
_sym_db.RegisterMessage(NewMetaDataRequest)
_sym_db.RegisterMessage(NewMetaDataRequest.MdInfosEntry)

GetCopyOfObjectRequest = _reflection.GeneratedProtocolMessageType('GetCopyOfObjectRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCOPYOFOBJECTREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.GetCopyOfObjectRequest)
  ))
_sym_db.RegisterMessage(GetCopyOfObjectRequest)

GetCopyOfObjectResponse = _reflection.GeneratedProtocolMessageType('GetCopyOfObjectResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCOPYOFOBJECTRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.GetCopyOfObjectResponse)
  ))
_sym_db.RegisterMessage(GetCopyOfObjectResponse)

UpdateObjectRequest = _reflection.GeneratedProtocolMessageType('UpdateObjectRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEOBJECTREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.UpdateObjectRequest)
  ))
_sym_db.RegisterMessage(UpdateObjectRequest)

GetObjectsRequest = _reflection.GeneratedProtocolMessageType('GetObjectsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETOBJECTSREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.GetObjectsRequest)
  ))
_sym_db.RegisterMessage(GetObjectsRequest)

GetObjectsResponse = _reflection.GeneratedProtocolMessageType('GetObjectsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETOBJECTSRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.GetObjectsResponse)
  ))
_sym_db.RegisterMessage(GetObjectsResponse)

GetFederatedObjectsRequest = _reflection.GeneratedProtocolMessageType('GetFederatedObjectsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETFEDERATEDOBJECTSREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.GetFederatedObjectsRequest)
  ))
_sym_db.RegisterMessage(GetFederatedObjectsRequest)

GetFederatedObjectsResponse = _reflection.GeneratedProtocolMessageType('GetFederatedObjectsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETFEDERATEDOBJECTSRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.GetFederatedObjectsResponse)
  ))
_sym_db.RegisterMessage(GetFederatedObjectsResponse)

FilterObjectRequest = _reflection.GeneratedProtocolMessageType('FilterObjectRequest', (_message.Message,), dict(
  DESCRIPTOR = _FILTEROBJECTREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.FilterObjectRequest)
  ))
_sym_db.RegisterMessage(FilterObjectRequest)

FilterObjectResponse = _reflection.GeneratedProtocolMessageType('FilterObjectResponse', (_message.Message,), dict(
  DESCRIPTOR = _FILTEROBJECTRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.FilterObjectResponse)
  ))
_sym_db.RegisterMessage(FilterObjectResponse)

GetReferencedObjectIDsRequest = _reflection.GeneratedProtocolMessageType('GetReferencedObjectIDsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREFERENCEDOBJECTIDSREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.GetReferencedObjectIDsRequest)
  ))
_sym_db.RegisterMessage(GetReferencedObjectIDsRequest)

GetReferencedObjectIDsResponse = _reflection.GeneratedProtocolMessageType('GetReferencedObjectIDsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETREFERENCEDOBJECTIDSRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.GetReferencedObjectIDsResponse)
  ))
_sym_db.RegisterMessage(GetReferencedObjectIDsResponse)

MakePersistentRequest = _reflection.GeneratedProtocolMessageType('MakePersistentRequest', (_message.Message,), dict(
  DESCRIPTOR = _MAKEPERSISTENTREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.MakePersistentRequest)
  ))
_sym_db.RegisterMessage(MakePersistentRequest)

FederateRequest = _reflection.GeneratedProtocolMessageType('FederateRequest', (_message.Message,), dict(
  DESCRIPTOR = _FEDERATEREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.FederateRequest)
  ))
_sym_db.RegisterMessage(FederateRequest)

UnfederateRequest = _reflection.GeneratedProtocolMessageType('UnfederateRequest', (_message.Message,), dict(
  DESCRIPTOR = _UNFEDERATEREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.UnfederateRequest)
  ))
_sym_db.RegisterMessage(UnfederateRequest)

ExecuteImplementationRequest = _reflection.GeneratedProtocolMessageType('ExecuteImplementationRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTEIMPLEMENTATIONREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.ExecuteImplementationRequest)
  ))
_sym_db.RegisterMessage(ExecuteImplementationRequest)

ExecuteImplementationResponse = _reflection.GeneratedProtocolMessageType('ExecuteImplementationResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTEIMPLEMENTATIONRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.ExecuteImplementationResponse)
  ))
_sym_db.RegisterMessage(ExecuteImplementationResponse)

SetNotVolatileRequest = _reflection.GeneratedProtocolMessageType('SetNotVolatileRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETNOTVOLATILEREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.SetNotVolatileRequest)
  ))
_sym_db.RegisterMessage(SetNotVolatileRequest)

NewVersionRequest = _reflection.GeneratedProtocolMessageType('NewVersionRequest', (_message.Message,), dict(
  DESCRIPTOR = _NEWVERSIONREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.NewVersionRequest)
  ))
_sym_db.RegisterMessage(NewVersionRequest)

NewVersionResponse = _reflection.GeneratedProtocolMessageType('NewVersionResponse', (_message.Message,), dict(

  VersionedIDsEntry = _reflection.GeneratedProtocolMessageType('VersionedIDsEntry', (_message.Message,), dict(
    DESCRIPTOR = _NEWVERSIONRESPONSE_VERSIONEDIDSENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.NewVersionResponse.VersionedIDsEntry)
    ))
  ,
  DESCRIPTOR = _NEWVERSIONRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.NewVersionResponse)
  ))
_sym_db.RegisterMessage(NewVersionResponse)
_sym_db.RegisterMessage(NewVersionResponse.VersionedIDsEntry)

ConsolidateVersionRequest = _reflection.GeneratedProtocolMessageType('ConsolidateVersionRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSOLIDATEVERSIONREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.ConsolidateVersionRequest)
  ))
_sym_db.RegisterMessage(ConsolidateVersionRequest)

UpsertObjectsRequest = _reflection.GeneratedProtocolMessageType('UpsertObjectsRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPSERTOBJECTSREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.UpsertObjectsRequest)
  ))
_sym_db.RegisterMessage(UpsertObjectsRequest)

NewReplicaRequest = _reflection.GeneratedProtocolMessageType('NewReplicaRequest', (_message.Message,), dict(
  DESCRIPTOR = _NEWREPLICAREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.NewReplicaRequest)
  ))
_sym_db.RegisterMessage(NewReplicaRequest)

NewReplicaResponse = _reflection.GeneratedProtocolMessageType('NewReplicaResponse', (_message.Message,), dict(
  DESCRIPTOR = _NEWREPLICARESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.NewReplicaResponse)
  ))
_sym_db.RegisterMessage(NewReplicaResponse)

MoveObjectsRequest = _reflection.GeneratedProtocolMessageType('MoveObjectsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MOVEOBJECTSREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.MoveObjectsRequest)
  ))
_sym_db.RegisterMessage(MoveObjectsRequest)

MoveObjectsResponse = _reflection.GeneratedProtocolMessageType('MoveObjectsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MOVEOBJECTSRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.MoveObjectsResponse)
  ))
_sym_db.RegisterMessage(MoveObjectsResponse)

RemoveObjectsRequest = _reflection.GeneratedProtocolMessageType('RemoveObjectsRequest', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEOBJECTSREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.RemoveObjectsRequest)
  ))
_sym_db.RegisterMessage(RemoveObjectsRequest)

JumpMapThreadMsg = _reflection.GeneratedProtocolMessageType('JumpMapThreadMsg', (_message.Message,), dict(

  JumpMapThreadEntry = _reflection.GeneratedProtocolMessageType('JumpMapThreadEntry', (_message.Message,), dict(
    DESCRIPTOR = _JUMPMAPTHREADMSG_JUMPMAPTHREADENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.JumpMapThreadMsg.JumpMapThreadEntry)
    ))
  ,
  DESCRIPTOR = _JUMPMAPTHREADMSG,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.JumpMapThreadMsg)
  ))
_sym_db.RegisterMessage(JumpMapThreadMsg)
_sym_db.RegisterMessage(JumpMapThreadMsg.JumpMapThreadEntry)

RemoveObjectsResponse = _reflection.GeneratedProtocolMessageType('RemoveObjectsResponse', (_message.Message,), dict(

  RemovedObjectsEntry = _reflection.GeneratedProtocolMessageType('RemovedObjectsEntry', (_message.Message,), dict(
    DESCRIPTOR = _REMOVEOBJECTSRESPONSE_REMOVEDOBJECTSENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.RemoveObjectsResponse.RemovedObjectsEntry)
    ))
  ,
  DESCRIPTOR = _REMOVEOBJECTSRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.RemoveObjectsResponse)
  ))
_sym_db.RegisterMessage(RemoveObjectsResponse)
_sym_db.RegisterMessage(RemoveObjectsResponse.RemovedObjectsEntry)

MigrateObjectsRequest = _reflection.GeneratedProtocolMessageType('MigrateObjectsRequest', (_message.Message,), dict(

  DestStorageLocsEntry = _reflection.GeneratedProtocolMessageType('DestStorageLocsEntry', (_message.Message,), dict(
    DESCRIPTOR = _MIGRATEOBJECTSREQUEST_DESTSTORAGELOCSENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.MigrateObjectsRequest.DestStorageLocsEntry)
    ))
  ,
  DESCRIPTOR = _MIGRATEOBJECTSREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.MigrateObjectsRequest)
  ))
_sym_db.RegisterMessage(MigrateObjectsRequest)
_sym_db.RegisterMessage(MigrateObjectsRequest.DestStorageLocsEntry)

MigratedObjects = _reflection.GeneratedProtocolMessageType('MigratedObjects', (_message.Message,), dict(
  DESCRIPTOR = _MIGRATEDOBJECTS,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.MigratedObjects)
  ))
_sym_db.RegisterMessage(MigratedObjects)

MigrateObjectsResponse = _reflection.GeneratedProtocolMessageType('MigrateObjectsResponse', (_message.Message,), dict(

  MigratedObjsEntry = _reflection.GeneratedProtocolMessageType('MigratedObjsEntry', (_message.Message,), dict(
    DESCRIPTOR = _MIGRATEOBJECTSRESPONSE_MIGRATEDOBJSENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.MigrateObjectsResponse.MigratedObjsEntry)
    ))
  ,
  DESCRIPTOR = _MIGRATEOBJECTSRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.MigrateObjectsResponse)
  ))
_sym_db.RegisterMessage(MigrateObjectsResponse)
_sym_db.RegisterMessage(MigrateObjectsResponse.MigratedObjsEntry)

ActivateTracingRequest = _reflection.GeneratedProtocolMessageType('ActivateTracingRequest', (_message.Message,), dict(
  DESCRIPTOR = _ACTIVATETRACINGREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.ActivateTracingRequest)
  ))
_sym_db.RegisterMessage(ActivateTracingRequest)

CloseSessionInDSRequest = _reflection.GeneratedProtocolMessageType('CloseSessionInDSRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLOSESESSIONINDSREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.CloseSessionInDSRequest)
  ))
_sym_db.RegisterMessage(CloseSessionInDSRequest)

DiskCollectRequest = _reflection.GeneratedProtocolMessageType('DiskCollectRequest', (_message.Message,), dict(

  RefsToUpdateEntry = _reflection.GeneratedProtocolMessageType('RefsToUpdateEntry', (_message.Message,), dict(
    DESCRIPTOR = _DISKCOLLECTREQUEST_REFSTOUPDATEENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.DiskCollectRequest.RefsToUpdateEntry)
    ))
  ,
  DESCRIPTOR = _DISKCOLLECTREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.DiskCollectRequest)
  ))
_sym_db.RegisterMessage(DiskCollectRequest)
_sym_db.RegisterMessage(DiskCollectRequest.RefsToUpdateEntry)

GetClassIDFromObjectInMemoryRequest = _reflection.GeneratedProtocolMessageType('GetClassIDFromObjectInMemoryRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCLASSIDFROMOBJECTINMEMORYREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.GetClassIDFromObjectInMemoryRequest)
  ))
_sym_db.RegisterMessage(GetClassIDFromObjectInMemoryRequest)

GetClassIDFromObjectInMemoryResponse = _reflection.GeneratedProtocolMessageType('GetClassIDFromObjectInMemoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCLASSIDFROMOBJECTINMEMORYRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.GetClassIDFromObjectInMemoryResponse)
  ))
_sym_db.RegisterMessage(GetClassIDFromObjectInMemoryResponse)

StoreToDBRequest = _reflection.GeneratedProtocolMessageType('StoreToDBRequest', (_message.Message,), dict(
  DESCRIPTOR = _STORETODBREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.StoreToDBRequest)
  ))
_sym_db.RegisterMessage(StoreToDBRequest)

GetFromDBRequest = _reflection.GeneratedProtocolMessageType('GetFromDBRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETFROMDBREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.GetFromDBRequest)
  ))
_sym_db.RegisterMessage(GetFromDBRequest)

GetFromDBResponse = _reflection.GeneratedProtocolMessageType('GetFromDBResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETFROMDBRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.GetFromDBResponse)
  ))
_sym_db.RegisterMessage(GetFromDBResponse)

UpdateToDBRequest = _reflection.GeneratedProtocolMessageType('UpdateToDBRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATETODBREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.UpdateToDBRequest)
  ))
_sym_db.RegisterMessage(UpdateToDBRequest)

DeleteToDBRequest = _reflection.GeneratedProtocolMessageType('DeleteToDBRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETETODBREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.DeleteToDBRequest)
  ))
_sym_db.RegisterMessage(DeleteToDBRequest)

UpdateRefsRequest = _reflection.GeneratedProtocolMessageType('UpdateRefsRequest', (_message.Message,), dict(

  RefsToUpdateEntry = _reflection.GeneratedProtocolMessageType('RefsToUpdateEntry', (_message.Message,), dict(
    DESCRIPTOR = _UPDATEREFSREQUEST_REFSTOUPDATEENTRY,
    __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.UpdateRefsRequest.RefsToUpdateEntry)
    ))
  ,
  DESCRIPTOR = _UPDATEREFSREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.UpdateRefsRequest)
  ))
_sym_db.RegisterMessage(UpdateRefsRequest)
_sym_db.RegisterMessage(UpdateRefsRequest.RefsToUpdateEntry)

GetRetainedReferencesResponse = _reflection.GeneratedProtocolMessageType('GetRetainedReferencesResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRETAINEDREFERENCESRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.GetRetainedReferencesResponse)
  ))
_sym_db.RegisterMessage(GetRetainedReferencesResponse)

ExistsRequest = _reflection.GeneratedProtocolMessageType('ExistsRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXISTSREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.ExistsRequest)
  ))
_sym_db.RegisterMessage(ExistsRequest)

ExistsResponse = _reflection.GeneratedProtocolMessageType('ExistsResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXISTSRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.ExistsResponse)
  ))
_sym_db.RegisterMessage(ExistsResponse)

ExistsInDBRequest = _reflection.GeneratedProtocolMessageType('ExistsInDBRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXISTSINDBREQUEST,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.ExistsInDBRequest)
  ))
_sym_db.RegisterMessage(ExistsInDBRequest)

ExistsInDBResponse = _reflection.GeneratedProtocolMessageType('ExistsInDBResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXISTSINDBRESPONSE,
  __module__ = 'dataclay.communication.grpc.messages.dataservice.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:dataclay.communication.grpc.dataservice.ExistsInDBResponse)
  ))
_sym_db.RegisterMessage(ExistsInDBResponse)


DESCRIPTOR._options = None
_DEPLOYMETACLASSESREQUEST_DEPLOYMENTPACKENTRY._options = None
_DEPLOYCLASSESREQUEST_CLASSESTODEPLOYENTRY._options = None
_DEPLOYCLASSESREQUEST_CLASSIDSENTRY._options = None
_DEPLOYCLASSESREQUEST_ASPECTSENTRY._options = None
_DEPLOYCLASSESREQUEST_YAMLSENTRY._options = None
_NEWPERSISTENTINSTANCEREQUEST_IFACEBITMAPSENTRY._options = None
_NEWMETADATAREQUEST_MDINFOSENTRY._options = None
_NEWVERSIONRESPONSE_VERSIONEDIDSENTRY._options = None
_JUMPMAPTHREADMSG_JUMPMAPTHREADENTRY._options = None
_REMOVEOBJECTSRESPONSE_REMOVEDOBJECTSENTRY._options = None
_MIGRATEOBJECTSREQUEST_DESTSTORAGELOCSENTRY._options = None
_MIGRATEOBJECTSRESPONSE_MIGRATEDOBJSENTRY._options = None
_DISKCOLLECTREQUEST_REFSTOUPDATEENTRY._options = None
_UPDATEREFSREQUEST_REFSTOUPDATEENTRY._options = None
# @@protoc_insertion_point(module_scope)
